@@ -168,7 +168,7 @@ Set/Get the upper bound for this Range
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
